@@ -33,6 +33,13 @@
 #include "selectdevicedlg.h"
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 
+
+static const gchar* const widget_datacd_tree = "treeview7";
+static const gchar* const widget_datacd_size = "optionmenu1";
+static const gchar* const widget_datacd_progressbar = "progressbar2";
+static const gchar* const widget_datacd_create = "createDataCDBtn";
+
+
 gdouble datadisksize = 0.0;
 GtkCellRenderer* contentrenderer = NULL;
 
@@ -426,7 +433,7 @@ datacd_on_edit(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(user_data != NULL);        
-    //g_signal_emit_by_name (contentrenderer, "edited", NULL, NULL);    
+    /*g_signal_emit_by_name (contentrenderer, "edited", NULL, NULL);*/    
 }
 
 
@@ -482,6 +489,7 @@ datacd_new()
 
 	/* First column which has an icon renderer and a text renderer packed in */
     GtkTreeViewColumn *col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
     gtk_tree_view_column_set_title(col, _("Contents"));
     GtkCellRenderer *renderer = gtk_cell_renderer_pixbuf_new();
     gtk_tree_view_column_pack_start(col, renderer, FALSE);
@@ -505,6 +513,7 @@ datacd_new()
 	
 	/* Second column to display the file/dir size */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Size"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -514,6 +523,7 @@ datacd_new()
 
 	/* Third column to display the human size of file/dir */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Size"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -523,6 +533,7 @@ datacd_new()
 	
 	/* Fourth column for the full path of the file/dir */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Full Path"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -531,6 +542,7 @@ datacd_new()
 	
 	/* Fifth column for the session bool */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Session"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -538,7 +550,6 @@ datacd_new()
 	gtk_tree_view_column_set_visible(col, FALSE);
 	gtk_tree_view_append_column(filelist, col);
 
-
 	/* Set the selection mode of the file list */
     gtk_tree_selection_set_mode(gtk_tree_view_get_selection(filelist),
 		GTK_SELECTION_MULTIPLE /*GTK_SELECTION_BROWSE*/);
@@ -608,6 +619,8 @@ datacd_import_session()
 	
 	if(response == GTK_RESPONSE_CANCEL)
 		return;
+    if(devices_prompt_for_disk(NULL, GB_WRITER) == GTK_RESPONSE_CANCEL)
+        return;
 	
 	gnomebaker_show_busy_cursor(TRUE);
 	
