@@ -31,51 +31,51 @@
 
 
 typedef void (*ExecFunc) (void *, void*);
-/*typedef gboolean (*ExecLibFunc) (void *, gint*);*/
 
 typedef enum
 {
-	RUNNABLE = 0,
-	SKIP,
+	RUNNING = 0,
+	SKIPPED,
 	CANCELLED,
 	FAILED,
-	COMPLETE
+	COMPLETED
 } ExecState;
 
 typedef struct
 {
-	gint argc;
-	gchar **argv;
+	GPtrArray* args;
 	pid_t pid;
-	gint exitCode;
+	gint exitCode;    
 	ExecState state;
+    GMutex* statemutex;
     ExecFunc libProc;
 	ExecFunc preProc;
 	ExecFunc readProc;
 	ExecFunc postProc;	
-    GMutex* mutex;
-    GCond* cond;
     gchar* workingdir;
-}ExecCmd;
+    gboolean piped;
+} ExecCmd;
 
 typedef struct
 {
-	gint cmdCount;
-	ExecCmd* cmds;
-	ExecFunc startProc;
-	ExecFunc endProc;
+    gchar* processtitle;
+    gchar* processdescription;
+	GList* cmds;
 	GError *err;
+    ExecState outcome;
 } Exec;
 
 
-Exec* exec_new(const gint cmds);
+Exec* exec_new(const gchar* processtitle, const gchar* processdescription);
+ExecCmd* exec_cmd_new(Exec* e);
 void exec_delete(Exec* self);
-ExecCmd* exec_add_cmd(Exec* self);
-gint exec_go (Exec * const e, gboolean onthefly);
-void exec_cmd_add_arg (ExecCmd * const e, const gchar * const format, const gchar* const value);
-void exec_cancel (const Exec * const e);
+void exec_run(Exec* e);
+void exec_stop(Exec* e);
+void exec_cmd_add_arg(ExecCmd* e, const gchar* format, ...);
+void exec_cmd_update_arg(ExecCmd* e, const gchar* argstart, const gchar* format, ...);
 GString* exec_run_cmd(const gchar* cmd);
-void exec_cmd_lock(ExecCmd* e);
-void exec_cmd_unlock(ExecCmd* e);
+ExecState exec_cmd_get_state(ExecCmd* e);
+ExecState exec_cmd_set_state(ExecCmd* e, ExecState state);
+gint exec_count_operations(const Exec* e);
 
 #endif	/*_EXEC_H_*/
