@@ -29,21 +29,18 @@
 #include <gnome.h>
 #include "exec.h"
 
-void cdda2wav_add_copy_args (ExecCmd * e);
-void cdrecord_add_iso_args (ExecCmd * const cdBurn, const gchar * const iso);
-void cdrecord_add_audio_args (ExecCmd * const cdBurn);
-void cdrecord_add_blank_args (ExecCmd * const cdBurn);
+void cdda2wav_add_copy_args(ExecCmd* e);
+void cdrecord_add_iso_args(ExecCmd* cdBurn, const gchar* iso);
+void cdrecord_add_audio_args(ExecCmd* cdBurn);
+void cdrecord_add_blank_args(ExecCmd* cdBurn);
 void cdrecord_add_create_audio_cd_args(ExecCmd* e, const GList* audiofiles);
-void dvdformat_add_args(ExecCmd * const dvdFormat);
-gboolean growisofs_add_args(ExecCmd * const e, GtkTreeModel* datamodel);
-void growisofs_add_iso_args(ExecCmd * const growisofs, const gchar *iso);
-gboolean mkisofs_add_args(ExecCmd* e, GtkTreeModel* datamodel, const gchar* iso);
-void readcd_add_copy_args (ExecCmd * e, const gchar* iso);
-void cdrdao_add_image_args(ExecCmd* cmd, const gchar* const toc_or_cue);
-void generic_read_proc(void *ex, void *buffer);
-void media_convert_add_args(ExecCmd * cmd, GSList* _elements);
-void media_next_element();
-
-void gstreamer_add_args(ExecCmd* cmd, GtkTreeModel *model);
+void dvdformat_add_args(ExecCmd* dvdFormat);
+gboolean growisofs_add_args(ExecCmd* e, GtkTreeModel* datamodel);
+void growisofs_add_iso_args(ExecCmd* growisofs, const gchar *iso);
+gboolean mkisofs_add_args(ExecCmd* e, GtkTreeModel* datamodel, const gchar* iso, const gboolean calculatesize);
+void mkisofs_add_calc_iso_size_args(ExecCmd* e, const gchar* iso);
+void readcd_add_copy_args(ExecCmd* e, const gchar* iso);
+void cdrdao_add_image_args(ExecCmd* cmd, const gchar* toc_or_cue);
+void gstreamer_add_args(ExecCmd* cmd, const gchar* from, const gchar* to);
 
 #endif	/*_EXECFUNCTIONS_H_*/
