@@ -27,6 +27,11 @@
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include "burn.h"			   
 
+
+static const gchar* const widget_browser_dirtree = "treeview4";
+static const gchar* const widget_browser_filelist = "treeview5";
+
+
 /* callback id, so we can block it! */
 gulong sel_changed_id;
 
@@ -69,11 +74,11 @@ static const gchar *HOME_LABEL = N_("Home");
 static const gchar *EMPTY_LABEL = N_("(empty)");
 static const gchar *DIRECTORY = N_("Folder");
 
-gchar* rightclickselection = NULL;
+static gchar* rightclickselection = NULL;
 
 
 
-void 
+static void 
 filebrowser_burn_cd_image(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -81,7 +86,7 @@ filebrowser_burn_cd_image(gpointer widget, gpointer user_data)
 }
 
 
-void 
+static void 
 filebrowser_burn_dvd_image(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -89,10 +94,10 @@ filebrowser_burn_dvd_image(gpointer widget, gpointer user_data)
 }
 
 
-void 
-filebrowser_on_show_hidden_changed(GConfClient *client,
+static void 
+filebrowser_on_show_hidden_changed(GConfClient* client,
                                    guint cnxn_id,
-                                   GConfEntry *entry,
+                                   GConfEntry* entry,
                                    gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -100,10 +105,10 @@ filebrowser_on_show_hidden_changed(GConfClient *client,
 }
 
 
-void
-filebrowser_on_show_humansize_changed(GConfClient *client,
+static void
+filebrowser_on_show_humansize_changed(GConfClient* client,
                                    guint cnxn_id,
-								   GConfEntry *entry,
+								   GConfEntry* entry,
 								   gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -126,7 +131,7 @@ filebrowser_on_show_humansize_changed(GConfClient *client,
 }
 
 
-GString* 
+static GString* 
 filebrowser_build_path(GtkTreeModel* model, GtkTreeIter* iter)
 {
 	GB_LOG_FUNC
@@ -181,9 +186,9 @@ filebrowser_build_path(GtkTreeModel* model, GtkTreeIter* iter)
 }
 
 
-gint
-filebrowser_list_sortfunc(GtkTreeModel *model, GtkTreeIter *a,
-                           GtkTreeIter *b, gpointer user_data)
+static gint
+filebrowser_list_sortfunc(GtkTreeModel* model, GtkTreeIter* a,
+                           GtkTreeIter* b, gpointer user_data)
 {
 	gchar *aname = NULL, *amime = NULL, *bname = NULL, *bmime = NULL;
 	gtk_tree_model_get (model, a, FL_COL_NAME, &aname, FL_COL_TYPE, &amime, -1);
@@ -209,7 +214,7 @@ filebrowser_list_sortfunc(GtkTreeModel *model, GtkTreeIter *a,
 }
 
 
-void 
+static void 
 filebrowser_populate(GtkTreeModel* treemodel,
 					GtkTreeIter* iter, 
 					GtkTreeView* treeview,
@@ -371,10 +376,8 @@ filebrowser_populate(GtkTreeModel* treemodel,
 }
 
 
-void
-filebrowser_sel_changed(
-    GtkTreeSelection * selection,
-    gpointer userdata)
+static void
+filebrowser_sel_changed(GtkTreeSelection* selection, gpointer userdata)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(selection != NULL);
@@ -405,11 +408,9 @@ filebrowser_sel_changed(
 }
 
 
-void        
-filebrowser_on_tree_expanding(GtkTreeView *treeview,
-				GtkTreeIter *iter,
-				GtkTreePath *path,
-				gpointer user_data)
+static void        
+filebrowser_on_tree_expanding(GtkTreeView* treeview, GtkTreeIter* iter,
+				            GtkTreePath* path, gpointer user_data)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(treeview != NULL);
@@ -422,8 +423,8 @@ filebrowser_on_tree_expanding(GtkTreeView *treeview,
 }
 
 
-gchar* 
-filebrowser_build_filename(GtkTreeModel *filemodel, GtkTreeIter *iter)
+static gchar* 
+filebrowser_build_filename(GtkTreeModel* filemodel, GtkTreeIter* iter)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(filemodel != NULL, NULL);
@@ -449,11 +450,9 @@ filebrowser_build_filename(GtkTreeModel *filemodel, GtkTreeIter *iter)
 }
 
 
-void
-filebrowser_foreach_fileselection(GtkTreeModel *filemodel,
-			  GtkTreePath *path,
-			  GtkTreeIter *iter,
-			  gpointer userdata)
+static void
+filebrowser_foreach_fileselection(GtkTreeModel* filemodel, GtkTreePath* path,
+			                     GtkTreeIter* iter, gpointer userdata)
 {
 	GB_LOG_FUNC	
 	g_return_if_fail(userdata != NULL);
@@ -468,28 +467,10 @@ filebrowser_foreach_fileselection(GtkTreeModel *filemodel,
 }
 
 
-void 
-filebrowser_refresh (void)
-{
-	GB_LOG_FUNC
-	GladeXML *xml = gnomebaker_getxml();
-	g_return_if_fail(xml != NULL);
-	GtkWidget *dirtree = glade_xml_get_widget(xml, widget_browser_dirtree);
-	g_return_if_fail(dirtree != NULL);
-	GtkWidget *filelist =  glade_xml_get_widget(xml, widget_browser_filelist);
-	g_return_if_fail(filelist != NULL);
-	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(dirtree));
-	g_return_if_fail(sel != NULL);
-	
-	g_signal_emit_by_name (sel, "changed", sel, filelist);
-}
-
-
-void
-filebrowser_on_drag_data_get (GtkWidget * widget,
-			      GdkDragContext * context,
-			      GtkSelectionData * selection_data,
-			      guint info, guint time, gpointer data)
+static void
+filebrowser_on_drag_data_get(GtkWidget* widget, GdkDragContext* context,
+			                 GtkSelectionData* selection_data,
+			                 guint info, guint time, gpointer data)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(widget != NULL);
@@ -527,24 +508,7 @@ filebrowser_on_drag_data_get (GtkWidget * widget,
 }
 
 
-GtkSelectionData* 
-filebrowser_get_selection(gboolean fromtree)
-{
-	GB_LOG_FUNC
-	
-	GtkWidget* tree = NULL;
-	if(fromtree)
-		tree = glade_xml_get_widget(gnomebaker_getxml(), widget_browser_dirtree);
-	else
-		tree = glade_xml_get_widget(gnomebaker_getxml(), widget_browser_filelist);
-	
-	GtkSelectionData* selection_data = g_new0(GtkSelectionData, 1);	
-	filebrowser_on_drag_data_get(tree, NULL, selection_data, 0, 0, NULL);
-	return selection_data;
-}
-
-
-void 
+static void 
 filebrowser_select_directory(const gchar* directory)
 {
 	GtkTreeView* dirtree = 
@@ -582,7 +546,7 @@ filebrowser_select_directory(const gchar* directory)
 }
 
 
-void 
+static void 
 filebrowser_on_open(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC	
@@ -593,8 +557,8 @@ filebrowser_on_open(gpointer widget, gpointer user_data)
 }
 
 
-gboolean
-filebrowser_on_button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+static gboolean
+filebrowser_on_button_pressed(GtkWidget* widget, GdkEventButton* event, gpointer user_data)
 {
 	GB_LOG_FUNC
 	g_return_val_if_fail(widget != NULL, FALSE);	
@@ -634,13 +598,12 @@ filebrowser_on_button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer
 				g_free(rightclickselection);
 					rightclickselection = filebrowser_build_filename(model, &iter);
 				
-				if(g_str_has_suffix(name, ".cue") || g_str_has_suffix(name, ".toc") || (g_ascii_strcasecmp(mime, "application/x-cd-image") == 0))
-				{	
+				if(gbcommon_str_has_suffix(name, ".cue") || gbcommon_str_has_suffix(name, ".toc") || (g_ascii_strcasecmp(mime, "application/x-cd-image") == 0))
 					gbcommon_append_menu_item_file(menu, _("_Burn CD Image"), 
-						"baker-cd-iso.png", (GCallback)filebrowser_burn_cd_image, view);	
+                        "baker-cd-iso.png", (GCallback)filebrowser_burn_cd_image, view);	
+                if(g_ascii_strcasecmp(mime, "application/x-cd-image") == 0)
                     gbcommon_append_menu_item_file(menu, _("_Burn DVD Image"), 
 						"baker-dvd-iso.png", (GCallback)filebrowser_burn_dvd_image, view);	
-				}				
 				g_free(name);
 				g_free(mime);
 			}							
@@ -659,7 +622,7 @@ filebrowser_on_button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer
 }
 
 
-void 
+static void 
 filebrowser_on_list_dbl_click(GtkTreeView* treeview, GtkTreePath* path,
                        	      GtkTreeViewColumn* col, gpointer userdata)
 {
@@ -685,7 +648,7 @@ filebrowser_on_list_dbl_click(GtkTreeView* treeview, GtkTreePath* path,
 }
 
 
-void 
+static void 
 filebrowser_on_tree_dbl_click(GtkTreeView* treeview, GtkTreePath* path,
                        	      GtkTreeViewColumn* col, gpointer userdata)
 {
@@ -700,10 +663,8 @@ filebrowser_on_tree_dbl_click(GtkTreeView* treeview, GtkTreePath* path,
 }
 
 
-void
-filebrowser_setup_tree(
-    GtkTreeView * dirtree,
-    GtkTreeView * filelist)
+static void
+filebrowser_setup_tree(GtkTreeView* dirtree, GtkTreeView* filelist)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(dirtree != NULL);
@@ -764,7 +725,7 @@ filebrowser_setup_tree(
 
 	/* Connect up the changed signal so we can populate the file list according
 	   to the selection in the dir tree */
-	sel_changed_id =g_signal_connect((gpointer) selection, "changed",
+	sel_changed_id = g_signal_connect((gpointer) selection, "changed",
 		G_CALLBACK(filebrowser_sel_changed), filelist);
 				
 	g_signal_connect((gpointer) dirtree, "row-expanded",
@@ -794,9 +755,8 @@ filebrowser_setup_tree(
 }
 
 
-void
-filebrowser_setup_list(
-    GtkTreeView * filelist)
+static void
+filebrowser_setup_list(GtkTreeView* filelist)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(filelist != NULL);
@@ -817,6 +777,7 @@ filebrowser_setup_list(
 
 	/* 1st column which has an icon renderer and a text renderer packed in */
     GtkTreeViewColumn *col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
     gtk_tree_view_column_set_title(col, _("File"));
     GtkCellRenderer *renderer = gtk_cell_renderer_pixbuf_new();
     gtk_tree_view_column_pack_start(col, renderer, FALSE);
@@ -831,6 +792,7 @@ filebrowser_setup_list(
 
 	/* 2nd column to add the size to */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Size"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -840,6 +802,7 @@ filebrowser_setup_list(
 
 	/* 3rd column to add the human readeable size to */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, "Size");
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -849,6 +812,7 @@ filebrowser_setup_list(
 
 	/* 4th column to add the mime type description to */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Type"));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
@@ -857,13 +821,13 @@ filebrowser_setup_list(
 	
 	/* 5th hidden column to add the mime type to */
 	col = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_resizable(col, TRUE);
 	gtk_tree_view_column_set_title(col, _("Mime"));
 	gtk_tree_view_column_set_visible(col, FALSE);
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(col, renderer, TRUE);
     gtk_tree_view_column_set_attributes(col, renderer, "text", FL_COL_MIME, NULL);
     gtk_tree_view_append_column(filelist, col);
-	
 
 	/* Set the selection mode of the file list */
     gtk_tree_selection_set_mode(gtk_tree_view_get_selection(filelist),
@@ -886,6 +850,40 @@ filebrowser_setup_list(
 }
 
 
+void 
+filebrowser_refresh()
+{
+    GB_LOG_FUNC
+    GladeXML *xml = gnomebaker_getxml();
+    g_return_if_fail(xml != NULL);
+    GtkWidget *dirtree = glade_xml_get_widget(xml, widget_browser_dirtree);
+    g_return_if_fail(dirtree != NULL);
+    GtkWidget *filelist =  glade_xml_get_widget(xml, widget_browser_filelist);
+    g_return_if_fail(filelist != NULL);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(dirtree));
+    g_return_if_fail(sel != NULL);
+    
+    g_signal_emit_by_name (sel, "changed", sel, filelist);
+}
+
+
+GtkSelectionData* 
+filebrowser_get_selection(gboolean fromtree)
+{
+    GB_LOG_FUNC
+    
+    GtkWidget* tree = NULL;
+    if(fromtree)
+        tree = glade_xml_get_widget(gnomebaker_getxml(), widget_browser_dirtree);
+    else
+        tree = glade_xml_get_widget(gnomebaker_getxml(), widget_browser_filelist);
+    
+    GtkSelectionData* selection_data = g_new0(GtkSelectionData, 1); 
+    filebrowser_on_drag_data_get(tree, NULL, selection_data, 0, 0, NULL);
+    return selection_data;
+}
+
+
 void
 filebrowser_new()
 {
