@@ -20,33 +20,40 @@
  */
  
 #include "gbcommon.h" 
+#include "gnomebaker.h"
 #include <sys/stat.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 
-GMutex* memsetlock = NULL;
-
-
 gboolean 
 gbcommon_init()
 {
     GB_LOG_FUNC
-    memsetlock = g_mutex_new();
     return TRUE;
 }
 
 
+void
+gb_common_finalise()
+{
+    GB_LOG_FUNC   
+}
+
+
 void 
 gbcommon_start_busy_cursor(GtkWidget* window)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(window != NULL);
-	GdkCursor* cursor = gdk_cursor_new(GDK_WATCH);
-	gdk_window_set_cursor(GDK_WINDOW(window->window), cursor);
-	gdk_cursor_destroy(cursor);/* safe because cursor is just a handle */
-	gdk_flush();
+    if(GTK_WIDGET_REALIZED(window))
+    {
+    	GdkCursor* cursor = gdk_cursor_new(GDK_WATCH);
+    	gdk_window_set_cursor(GDK_WINDOW(window->window), cursor);
+    	gdk_cursor_destroy(cursor);/* safe because cursor is just a handle */
+    	gdk_flush();
+    }
 }
 
 
@@ -65,8 +72,11 @@ gbcommon_end_busy_cursor(GtkWidget* window)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(window != NULL);
-	gdk_window_set_cursor(GDK_WINDOW(window->window), NULL); /* set back to default cursor */
-	gdk_flush();
+    if(GTK_WIDGET_REALIZED(window))
+    {
+    	gdk_window_set_cursor(GDK_WINDOW(window->window), NULL); /* set back to default cursor */
+    	gdk_flush();
+    }
 }
 
 
@@ -272,8 +282,7 @@ gbcommon_launch_app_for_file(const gchar* file)
 		if(app != NULL)
 		{			
 			gchar* uri = gnome_vfs_get_uri_from_local_path(file);
-			GList* uris = NULL;
-			uris = g_list_append(uris, uri);
+			GList* uris = g_list_append(NULL, uri);
 			gnome_vfs_mime_application_launch(app, uris);
 			g_free(uri);
 			g_list_free(uris);
@@ -430,48 +439,53 @@ gbcommon_append_menu_item_file(GtkWidget* menu, const gchar* menuitemlabel, cons
 	g_object_unref(pixbuf);
 }
 
+
 gchar*
-gbcommon_show_iso_dlg()
+gbcommon_show_file_chooser(const gchar* title, GtkFileFilter* imagefilter)
 {
 	GB_LOG_FUNC
+    g_return_val_if_fail(title != NULL, NULL);
+    g_return_val_if_fail(imagefilter != NULL, NULL);
+    
 	gchar* file = NULL;
-	
-	GtkWidget *filesel = gtk_file_chooser_dialog_new(
-	    _("Please select an iso file..."), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, 
+	GtkWidget *filesel = gtk_file_chooser_dialog_new( title , NULL, GTK_FILE_CHOOSER_ACTION_OPEN, 
 	    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
-	
 	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(filesel), FALSE);
-	GtkFileFilter *imagefilter = gtk_file_filter_new();
-	gtk_file_filter_add_pattern (imagefilter, "*.iso");
-	gtk_file_filter_add_pattern (imagefilter, "*.toc");
-	gtk_file_filter_add_pattern (imagefilter, "*.cue");
-	gtk_file_filter_set_name(imagefilter,_("CD Image files"));
 	GtkFileFilter *allfilter = gtk_file_filter_new();
 	gtk_file_filter_add_pattern (allfilter, "*");
 	gtk_file_filter_set_name(allfilter,_("All files"));
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(filesel), imagefilter);
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(filesel), allfilter);
-	
 	const gint result = gtk_dialog_run(GTK_DIALOG(filesel));
 	file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filesel));
-
 	gtk_widget_destroy(filesel);
-	
 	if(result != GTK_RESPONSE_OK)
-	{
 		file = NULL;
-	}
 	return file;
-	
 }
 
 
 void 
-gbcommon_memset(void* memory, gsize size)
+gbcommon_center_window_on_parent(GtkWidget* window)
 {
-    /*GB_LOG_FUNC*/
-    g_return_if_fail(memory != NULL);
-    g_mutex_lock(memsetlock);
-    memset(memory, 0x0, size);
-    g_mutex_unlock(memsetlock);
+    GB_LOG_FUNC    
+    g_return_if_fail(window != NULL);
+    
+    GtkWindow* mainwindow = gnomebaker_get_window();
+    gtk_window_set_transient_for(GTK_WINDOW(window), GTK_WINDOW(mainwindow));
+    gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER_ON_PARENT);
+    gtk_widget_show(window);
 }
+
+
+gboolean 
+gbcommon_str_has_suffix(const gchar* str, const gchar* suffix)
+{
+    GB_LOG_FUNC
+    g_return_val_if_fail(str != NULL, FALSE);
+    g_return_val_if_fail(suffix != NULL, FALSE);
+    return (g_ascii_strcasecmp(str + strlen(str) - strlen(suffix), suffix) == 0);
+}
+
+
+
