@@ -34,13 +34,28 @@
 #include "splashdlg.h"
 #include "gbcommon.h"
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include "gst/gst.h"
+#include <gst/gst.h>
 #include "media.h"
 
-GladeXML *xml = NULL;
+static const gchar* const widget_gnomebaker = "GnomeBaker";
+static const gchar* const widget_project_notebook = "notebook1";
+static const gchar* const widget_appbar = "appbar1";
+static const gchar* const widget_import = "toolbutton5";
+static const gchar* const widget_up = "toolbutton8";
+static const gchar* const widget_down = "toolbutton9";
+static const gchar* const widget_top_toolbar_dock = "bonobodockitem4";
+static const gchar* const widget_top_toolbar = "toolbar3";
+static const gchar* const widget_middle_toolbar = "toolbar4";
+static const gchar* const widget_show_browser_menu = "show_file_browser1";
+static const gchar* const widget_browser_hpane = "hpaned3";
+static const gchar* const widget_add_button = "buttonAddFiles";
+static const gchar* const widget_refresh_menu = "refresh1";
+static const gchar* const widget_refresh_button = "toolbutton4";
+
+static GladeXML *xml = NULL;
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_show_file_browser(GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -58,7 +73,7 @@ gnomebaker_on_show_file_browser(GtkCheckMenuItem *checkmenuitem, gpointer user_d
 }
 
 
-void 
+static void 
 gnomebaker_on_toolbar_style_changed(GConfClient *client,
                                    guint cnxn_id,
                                    GConfEntry *entry,
@@ -91,11 +106,11 @@ gnomebaker_new()
 	devices_init();
 
 	splashdlg_set_text(_("Registering gstreamer plugins..."));
-	media_register_plugins();
+	media_init();
 
 	splashdlg_set_text(_("Loading GUI..."));
 	xml = glade_xml_new(glade_file, widget_gnomebaker, NULL);
-
+    
 	/* This is important */
 	glade_xml_signal_autoconnect(xml);			
 
@@ -103,7 +118,7 @@ gnomebaker_new()
 	filebrowser_new();	
 	datacd_new();
 	audiocd_new();
-	
+        
 	/* Get and set the default toolbar style */
 	gnomebaker_on_toolbar_style_changed(NULL, 0, NULL, NULL);
 	preferences_register_notify(GNOME_TOOLBAR_STYLE, gnomebaker_on_toolbar_style_changed);
@@ -125,7 +140,7 @@ gnomebaker_new()
 
 	g_main_context_iteration(NULL, TRUE);
 	
-	GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+	GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
 	gtk_notebook_remove_page(GTK_NOTEBOOK(notebook), -1);
 	
 	GtkWidget* checkmenuitem = glade_xml_get_widget(xml, widget_show_browser_menu);
@@ -133,6 +148,8 @@ gnomebaker_new()
 		preferences_get_bool(GB_SHOW_FILE_BROWSER));
 	g_signal_emit_by_name(checkmenuitem, "toggled", checkmenuitem, NULL);	
 
+	gtk_widget_show_all (main_window);
+
 	return main_window;
 }
 
@@ -141,6 +158,9 @@ void
 gnomebaker_delete(GtkWidget* self)
 {
 	GB_LOG_FUNC
+    media_finalise();
+    preferences_finalise();
+    gb_common_finalise();
 	gtk_widget_hide(self);
 	gtk_widget_destroy(self);
 	g_free(xml);
@@ -168,7 +188,7 @@ gnomebaker_show_msg_dlg(GtkWindow* parent, GtkMessageType type,
 }
 
 
-void
+void /* libglade callback */
 gnomebaker_on_quit(GtkMenuItem * menuitem, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -227,59 +247,65 @@ gnomebaker_on_quit(GtkMenuItem * menuitem, gpointer user_data)
 }
 
 
-void
+void /* libglade callback */
 gnomebaker_on_blank_cdrw(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
-
 	burn_blank_cdrw();	
 }
 
-void
+
+static gboolean
+gnomebaker_cd_image_file_filter(const GtkFileFilterInfo *filter_info, gpointer data)
+{
+    GB_LOG_FUNC
+    if(gbcommon_str_has_suffix(filter_info->filename, ".cue") || 
+            gbcommon_str_has_suffix(filter_info->filename, ".toc") || 
+            (g_ascii_strcasecmp(filter_info->mime_type, "application/x-cd-image") == 0))
+        return TRUE;
+    return FALSE;
+}
+
+
+void /* libglade callback */
 gnomebaker_on_burn_iso(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
-		
-	const gchar* file = gbcommon_show_iso_dlg();
+    GtkFileFilter *imagefilter = gtk_file_filter_new();
+    gtk_file_filter_add_custom(imagefilter, GTK_FILE_FILTER_FILENAME | GTK_FILE_FILTER_MIME_TYPE,
+        gnomebaker_cd_image_file_filter, NULL, NULL);
+    gtk_file_filter_set_name(imagefilter,_("CD Image files"));
+	const gchar* file = gbcommon_show_file_chooser(_("Please select a CD image file."), imagefilter);
 	if(file != NULL)
-	{
-		GB_TRACE("file is %s", file);		
 		burn_cd_image_file(file);
-	}
 }
 
-void
+
+static gboolean
+gnomebaker_dvd_image_file_filter(const GtkFileFilterInfo *filter_info, gpointer data)
+{
+    GB_LOG_FUNC
+    if(g_ascii_strcasecmp(filter_info->mime_type, "application/x-cd-image") == 0)
+        return TRUE;
+    return FALSE;
+}
+
+
+void /* libglade callback */
 gnomebaker_on_burn_dvd_iso(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
-		
-	const gchar* file = gbcommon_show_iso_dlg();
+    GtkFileFilter *imagefilter = gtk_file_filter_new();
+    gtk_file_filter_add_custom(imagefilter, GTK_FILE_FILTER_MIME_TYPE,
+        gnomebaker_dvd_image_file_filter, NULL, NULL);
+    gtk_file_filter_set_name(imagefilter,_("DVD Image files"));
+	const gchar* file = gbcommon_show_file_chooser(_("Please select a DVD image file."), imagefilter);
 	if(file != NULL)
-	{
-		GB_TRACE("file is %s", file);
-		
-		gchar* mime = gnome_vfs_get_mime_type(file);
-		g_return_if_fail(mime != NULL);
-		GB_TRACE("mime type is %s for %s", mime, file);
-		
-		/* Check that the mime type is iso */
-		if(g_ascii_strcasecmp(mime, "application/x-cd-image") == 0)
-		{
-			burn_dvd_iso(file);
-		}
-		else
-		{
-			gnomebaker_show_msg_dlg(NULL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, GTK_BUTTONS_NONE,
-			  _("The file you have selected is not a DVD image. Please select a DVD image to burn."));
-		}
-		
-		g_free(mime);
-	}
+        burn_dvd_iso(file);
 }
 
 
-
-void
+void /* libglade callback */
 gnomebaker_on_preferences(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -289,7 +315,7 @@ gnomebaker_on_preferences(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_copy_datacd(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -297,7 +323,7 @@ gnomebaker_on_copy_datacd(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_copy_audiocd(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -329,8 +355,7 @@ gnomebaker_window_state_event(GtkWidget* widget, GdkEvent* event, gpointer user_
 }
 
 
-
-void
+void /* libglade callback */
 gnomebaker_on_about(GtkMenuItem * menuitem, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -341,10 +366,10 @@ gnomebaker_on_about(GtkMenuItem * menuitem, gpointer user_data)
     }
 	else
 	{
-		const gchar* authors[] = {"Luke Biddell", "Christoffer Sørensen", "Razvan Gavril", "Isak Savo", NULL};
+		const gchar* authors[] = {"Luke Biddell", "Christoffer Sørensen", "Razvan Gavril", "Isak Savo", "Adam Biddell (Sounds)", NULL};
 		const gchar* documenters[] = {"Milen Dzhumerov", NULL};
 		about = gnome_about_new(_("GnomeBaker"), VERSION, "GPL", 
-			_("Simple CD Burning for Gnome"), authors, documenters, _("translator_credits"), 
+			_("Simple CD/DVD Burning for Gnome"), authors, documenters, _("translator_credits"), 
 			gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR"/splash_2.png", NULL));
 		g_object_add_weak_pointer(G_OBJECT(about), (void**)&about);
 		gtk_widget_show(about);	
@@ -371,13 +396,13 @@ gnomebaker_show_busy_cursor(gboolean isbusy)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_add_dir(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
 	
 	GtkSelectionData* selection_data = filebrowser_get_selection(TRUE);
-	GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+	GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
 	switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
 	{
 		case 0:
@@ -393,7 +418,7 @@ gnomebaker_on_add_dir(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_add_files(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -409,7 +434,7 @@ gnomebaker_on_add_files(gpointer widget, gpointer user_data)
     else
     {
         GtkWidget *filesel = gtk_file_chooser_dialog_new(
-	        _("Please select files to add to the disk..."), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, 
+	        _("Please select files to add to the disk."), NULL, GTK_FILE_CHOOSER_ACTION_OPEN , 
 	        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
         
         gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(filesel), TRUE);     
@@ -417,7 +442,7 @@ gnomebaker_on_add_files(gpointer widget, gpointer user_data)
         {
             
             GSList* files = gtk_file_chooser_get_uris(GTK_FILE_CHOOSER(filesel));
-            //gchar** uris = g_malloc0(g_slist_length(files) * sizeof(gchar*));
+            /*gchar** uris = g_malloc0(g_slist_length(files) * sizeof(gchar*));*/
             
             GSList* file = files;
             int index = 0;
@@ -429,16 +454,16 @@ gnomebaker_on_add_files(gpointer widget, gpointer user_data)
                 g_string_append(text, (gchar*)file->data);
                 g_string_append(text, "\n");
                 g_free((gchar*)file->data);
-                //uris[index++] = (gchar*)file->data;
+                /*uris[index++] = (gchar*)file->data;*/
             }
             
-            //gtk_selection_data_set_uris(selection_data, uris);            
+            /*gtk_selection_data_set_uris(selection_data, uris);*/
             selection_data = g_new0(GtkSelectionData, 1);	                 
             gtk_selection_data_set(selection_data, selection_data->target, 8, 
                 (const guchar*)text->str, strlen(text->str) * sizeof(gchar));
             GB_TRACE("[%s]", selection_data->data);
             g_slist_free(files);
-            //g_strfreev(uris);
+            /*g_strfreev(uris);*/
             g_string_free(text, TRUE);
         }
         gtk_widget_destroy(filesel);
@@ -446,7 +471,7 @@ gnomebaker_on_add_files(gpointer widget, gpointer user_data)
     
     if(selection_data != NULL)
     {
-        GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);	
+        GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);	
         switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
         {
             case 0:
@@ -463,12 +488,12 @@ gnomebaker_on_add_files(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_remove(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
 	
-	GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+	GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
 	g_return_if_fail(notebook != NULL);	
 	switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
 	{
@@ -483,12 +508,12 @@ gnomebaker_on_remove(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_clear(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
 	
-	GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+	GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
 	g_return_if_fail(notebook != NULL);	
 	switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
 	{
@@ -529,7 +554,7 @@ gnomebaker_enable_widget(const gchar* widgetname, gboolean enabled)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_refresh(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -537,12 +562,12 @@ gnomebaker_on_refresh(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_import(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
 	
-	GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+	GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
 	g_return_if_fail(notebook != NULL);		
 	switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
 	{
@@ -557,7 +582,7 @@ gnomebaker_on_import(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_format_dvdrw(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -565,7 +590,7 @@ gnomebaker_on_format_dvdrw(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_help(gpointer widget, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -579,6 +604,7 @@ gnomebaker_on_help(gpointer widget, gpointer user_data)
 	}	
 }
 
+
 void
 gnomebaker_on_notebook_switch_page(GtkNotebook *notebook,
                                    GtkNotebookPage *page,
@@ -605,12 +631,13 @@ gnomebaker_on_notebook_switch_page(GtkNotebook *notebook,
     };
 }
 
-void 
+
+void /* libglade callback */
 gnomebaker_on_up(gpointer widget, gpointer user_data)
 {
     GB_LOG_FUNC
     
-    GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+    GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
     g_return_if_fail(notebook != NULL);     
     switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
     {
@@ -624,12 +651,12 @@ gnomebaker_on_up(gpointer widget, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 gnomebaker_on_down(gpointer widget, gpointer user_data)
 {
     GB_LOG_FUNC
     
-    GtkWidget *notebook = glade_xml_get_widget(xml, widget_datacd_notebook);
+    GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
     g_return_if_fail(notebook != NULL);     
     switch(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))
     {
@@ -641,3 +668,42 @@ gnomebaker_on_down(gpointer widget, gpointer user_data)
         default:{}  
     };
 }
+
+
+GtkWindow* 
+gnomebaker_get_window()
+{
+    GB_LOG_FUNC
+    return GTK_WINDOW(glade_xml_get_widget(gnomebaker_getxml(), widget_gnomebaker));
+}
+
+
+static gboolean
+gnomebaker_playlist_file_filter(const GtkFileFilterInfo *filter_info, gpointer data)
+{
+    GB_LOG_FUNC
+    return audiocd_is_supported_playlist(filter_info->mime_type);
+}
+
+
+void /* libglade callback */
+gnomebaker_on_import_playlist(gpointer widget, gpointer user_data)
+{
+    GB_LOG_FUNC
+        
+    GtkFileFilter *imagefilter = gtk_file_filter_new();
+    gtk_file_filter_add_custom(imagefilter, GTK_FILE_FILTER_FILENAME | GTK_FILE_FILTER_MIME_TYPE,
+        gnomebaker_playlist_file_filter, NULL, NULL);
+    gtk_file_filter_set_name(imagefilter,_("Playlist files"));
+    const gchar* file = gbcommon_show_file_chooser(_("Please select a playlist."), imagefilter);
+    if(file != NULL)
+    {
+        if(audiocd_import_playlist(file))
+        {
+            GtkWidget *notebook = glade_xml_get_widget(xml, widget_project_notebook);
+            gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
+        }
+    }
+}
+
+
