@@ -30,11 +30,12 @@
 #include "gbcommon.h"
 #include <libintl.h>
 #include <locale.h>
-#include "gst/gst.h"
+#include <gst/gst.h>
 
 const gchar* glade_file;
 gboolean showtrace = FALSE;
 
+
 gint 
 main(gint argc, gchar *argv[])
 {	
@@ -50,6 +51,7 @@ main(gint argc, gchar *argv[])
 	
 	g_thread_init(NULL);
 	gdk_threads_init();
+	
 
 	#ifdef ENABLE_NLS
 		setlocale(LC_ALL,"");		
@@ -58,53 +60,37 @@ main(gint argc, gchar *argv[])
 		textdomain (GETTEXT_PACKAGE);
 	#endif
 	
-	/*gnome_init(PACKAGE, VERSION, argc, argv);*/
-/*	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-                      argc, argv,
-                      GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
-                      NULL);
-*/
-	 struct poptOption options[] = {
-    {NULL, '\0', POPT_ARG_INCLUDE_TABLE, NULL, 0, "GStreamer", NULL},
-    POPT_TABLEEND
-  };
+	struct poptOption options[] = 
+	{
+    	{NULL, '\0', POPT_ARG_INCLUDE_TABLE, NULL, 0, "GStreamer", NULL},
+    	POPT_TABLEEND
+	};
 
-  /* init GStreamer and GNOME using the GStreamer popt tables */
-  options[0].arg = (void *) gst_init_get_popt_table ();
-	
-  gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-                      argc, argv,
-                      GNOME_PARAM_POPT_TABLE, options,
-  					  GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
-                      NULL);
+	/* init GStreamer and GNOME using the GStreamer popt tables */
+	options[0].arg = (void *) gst_init_get_popt_table ();
 
-	
+	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+                    argc, argv, GNOME_PARAM_POPT_TABLE, options,
+                    GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR, NULL);
 
 	glade_gnome_init();
 	
-	glade_file = gnome_program_locate_file(
-		NULL,
-		GNOME_FILE_DOMAIN_APP_DATADIR,
-		"gnomebaker/gnomebaker.glade",
-		FALSE,
-		NULL);
-		
-	/*gtk_window_set_auto_startup_notification(TRUE);*/
-
-	GtkWidget* dlg = splashdlg_new();
-		
-	while(g_main_context_pending(NULL))
-		g_main_context_iteration(NULL, TRUE);
+	glade_file = gnome_program_locate_file(NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
+					"gnomebaker/gnomebaker.glade", FALSE, NULL);                
 	
+	GtkWidget* dlg = splashdlg_new();		
+	while(g_main_context_pending(NULL))
+		g_main_context_iteration(NULL, TRUE);	
 	GtkWidget* app = gnomebaker_new();
-
 	splashdlg_delete(dlg);
 	
-	gdk_threads_enter();
+    gdk_threads_enter();	
 	gtk_main();
-	gdk_threads_leave();
-	
+	gdk_threads_leave();	
 	gnomebaker_delete(app);
 	
 	return 0;
 }
+
+
+
