@@ -37,7 +37,7 @@ preferences_init()
 	GB_LOG_FUNC
 	
 	gboolean ok = FALSE;	
-	
+	g_type_init();
 	gconf_client = gconf_client_get_default();
 	if(gconf_client == NULL) 
 	{
@@ -70,6 +70,8 @@ preferences_init()
             preferences_set_bool(GB_JOLIET, TRUE);
             preferences_set_bool(GB_ROCKRIDGE, TRUE);
             preferences_set_bool(GB_ONTHEFLY, TRUE);
+            preferences_set_bool(GB_ASK_ON_QUIT, TRUE);
+            preferences_set_bool(GB_PLAY_SOUND, TRUE);
 		}		
 		
 		gbcommon_mkdir(tempdir);
@@ -81,6 +83,14 @@ preferences_init()
 }
 
 
+void
+preferences_finalise()
+{
+    GB_LOG_FUNC
+    g_object_unref(G_OBJECT(gconf_client));   
+}
+
+
 gchar* 
 preferences_get_copy_data_cd_image()
 {
