@@ -49,6 +49,7 @@
 #define GB_ROCKRIDGE                GB_BASE_KEY "/RockRidge"
 #define GB_ONTHEFLY                 GB_BASE_KEY "/OnTheFly"
 #define GB_ASK_ON_QUIT				GB_BASE_KEY "/AskOnQuit"
+#define GB_PLAY_SOUND               GB_BASE_KEY "/PlaySound"
 
 #define GB_MAIN_WINDOW_HEIGHT		GB_BASE_KEY "/UI/MainWindowHeight"
 #define GB_MAIN_WINDOW_WIDTH		GB_BASE_KEY "/UI/MainWindowWidth"
@@ -74,7 +75,8 @@
 #define GNOME_TOOLBAR_STYLE		 "/desktop/gnome/interface/toolbar_style"
 #define GNOME_TOOLBAR_DETACHABLE "/desktop/gnome/interface/toolbar_detachable"
 
-gboolean preferences_init ();
+gboolean preferences_init();
+void preferences_finalise();
 
 gchar* preferences_get_copy_data_cd_image();
 gchar* preferences_get_create_data_cd_image();
