@@ -26,6 +26,18 @@
 #include "devices.h"
 
 
+/* Prefs dialog glade widget names */
+static const gchar* const widget_prefsdlg = "prefsDlg";
+static const gchar* const widget_prefsdlg_tempdir = "tmpDirEntry";
+static const gchar* const widget_prefsdlg_cleantempdir = "checkCleanTmp";
+static const gchar* const widget_prefsdlg_showhidden = "checkHiddenFiles";
+static const gchar* const widget_prefsdlg_askonquit = "checkAskOnQuit";
+static const gchar* const widget_prefsdlg_playsound = "checkPlaySound";
+static const gchar* const widget_prefsdlg_showhumansize = "checkShowHumanSizes";
+static const gchar* const widget_prefsdlg_alwaysscan = "checkAlwaysScan";
+static const gchar* const widget_prefsdlg_devicelist = "treeview12";
+
+
 static const gint DEVICELIST_COL_ICON = 0;
 static const gint DEVICELIST_COL_NAME = 1;
 static const gint DEVICELIST_COL_ID = 2;
@@ -38,10 +50,10 @@ static const gint DEVICELIST_WRITE_DVDRAM = 8;
 static const gint DEVICELIST_NUM_COLS = 9;
 
 
-GladeXML* prefsdlg_xml = NULL;
+static GladeXML* prefsdlg_xml = NULL;
 
 
-void
+static void
 prefsdlg_device_cell_edited(GtkCellRendererText *cell,
 							gchar* path_string,
 							gchar* new_text,
@@ -76,7 +88,7 @@ prefsdlg_device_cell_edited(GtkCellRendererText *cell,
 }
 
 
-void
+static void
 prefsdlg_device_capability_edited(GtkCellRendererToggle *cell,
                                    gchar *path, gpointer user_data)
 {
@@ -108,7 +120,7 @@ prefsdlg_device_capability_edited(GtkCellRendererToggle *cell,
 }
 
 
-void 
+static void 
 prefsdlg_create_device_list()
 {
 	GB_LOG_FUNC
@@ -208,7 +220,7 @@ prefsdlg_create_device_list()
 }
 
 
-gboolean
+static gboolean
 prefsdlg_foreach_device(GtkTreeModel *devicemodel,
 					  GtkTreePath *path,
 					  GtkTreeIter *iter,
@@ -250,7 +262,7 @@ prefsdlg_foreach_device(GtkTreeModel *devicemodel,
 }
 
 	
-void 
+void /* libglade callback */
 prefsdlg_on_ok(GtkButton* button, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -273,8 +285,11 @@ prefsdlg_on_ok(GtkButton* button, gpointer user_data)
 	GtkWidget* checkAlwaysScan = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_alwaysscan);
 	preferences_set_bool(GB_ALWAYS_SCAN, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkAlwaysScan)));
 	
-	GtkWidget* checkAskOnQuit = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_askonquit);
-	preferences_set_bool(GB_ASK_ON_QUIT, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkAskOnQuit)));
+	GtkWidget* checkPlaySound = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_playsound);
+	preferences_set_bool(GB_PLAY_SOUND, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkPlaySound)));
+    
+    GtkWidget* checkAskOnQuit = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_askonquit);
+    preferences_set_bool(GB_ASK_ON_QUIT, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkAskOnQuit)));
 	
 	GtkWidget* devicelist = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_devicelist);
 	g_return_if_fail(devicelist != NULL);
@@ -285,7 +300,7 @@ prefsdlg_on_ok(GtkButton* button, gpointer user_data)
 }
 
 
-void 
+static void 
 prefsdlg_populate_device_list()
 {	
 	GB_LOG_FUNC
@@ -346,7 +361,7 @@ prefsdlg_populate_device_list()
 }
 
 
-void
+static void
 prefsdlg_clear_device_list()
 {
 	GB_LOG_FUNC
@@ -360,7 +375,7 @@ prefsdlg_clear_device_list()
 }
 
 
-void 
+void /* libglade callback */
 prefsdlg_on_scan(GtkButton * button, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -375,7 +390,7 @@ prefsdlg_on_scan(GtkButton * button, gpointer user_data)
 }
 
 
-void 
+void /* libglade callback */
 prefsdlg_on_add(GtkButton * button, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -396,7 +411,7 @@ prefsdlg_on_add(GtkButton * button, gpointer user_data)
 }
 
 
-gboolean
+gboolean /* libglade callback */
 prefsdlg_on_delete(GtkWidget* widget, GdkEvent* event, gpointer user_data)
 {
 	GB_LOG_FUNC
@@ -433,14 +448,19 @@ prefsdlg_new(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAlwaysScan), 
 		preferences_get_bool(GB_ALWAYS_SCAN));
 		
+    GtkWidget* checkPlaySound = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_playsound);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkPlaySound), 
+        preferences_get_bool(GB_PLAY_SOUND));
+        
 	GtkWidget* checkAskOnQuit = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg_askonquit);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAskOnQuit), 
 		preferences_get_bool(GB_ASK_ON_QUIT));
 	
 	prefsdlg_create_device_list();
 	prefsdlg_populate_device_list();
-	
-	return glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg);
+	GtkWidget* dlg = glade_xml_get_widget(prefsdlg_xml, widget_prefsdlg);
+    gbcommon_center_window_on_parent(dlg);
+	return dlg;
 }
 
 
