@@ -20,42 +20,60 @@
  */
 
 #include "progressdlg.h"
-#include "burn.h"
 #include "gbcommon.h"
 #include <glib/gprintf.h>
+#include "preferences.h"
+#include "media.h"
 
+/* Progress dialog glade widget names */
+static const gchar* const widget_progdlg = "progDlg";
+static const gchar* const widget_progdlg_progbar = "progressbar6";
+static const gchar* const widget_progdlg_output = "textview1";
+static const gchar* const widget_progdlg_output_scroll = "scrolledwindow17";
+static const gchar* const widget_progdlg_toggleoutputlabel = "label249";
+static const gchar* const widget_progdlg_processtitle = "label295";
+static const gchar* const widget_progdlg_processdescription = "label296";
 
-GladeXML* progdlg_xml = NULL;
-GtkProgressBar* progbar = NULL;
-GtkTextView* textview = NULL;
-GtkTextBuffer* textBuffer = NULL;
-GtkWidget* textviewScroll = NULL;
+static GladeXML* progdlg_xml = NULL;
+static GtkProgressBar* progbar = NULL;
+static GtkTextView* textview = NULL;
+static GtkTextBuffer* textBuffer = NULL;
+static GtkWidget* textviewScroll = NULL;
+
+static gint timertag = 0;
+static gint numberofexecs = 0;
+static gint currentexec = -1;
+static GCallback closefunction = NULL;
 
-gint x = 0;
-gint y = 0;
-gint timertag = 0;
-gint numberofexecs = 0;
-gint currentexec = -1;
-gboolean showing = TRUE;
 
 GtkWidget* 
-progressdlg_new(gint numberofoperations)
+progressdlg_new(const Exec* exec, GCallback callonprematureclose)
 {		
 	GB_LOG_FUNC
-	numberofexecs = numberofoperations;
+    closefunction = callonprematureclose;
+	numberofexecs = exec_count_operations(exec);
 	currentexec = -1;
-	showing = TRUE;
 	progdlg_xml = glade_xml_new(glade_file, widget_progdlg, NULL);
 	glade_xml_signal_autoconnect(progdlg_xml);		
-	progressdlg_enable_close(FALSE);	
+    GtkWidget* widget = glade_xml_get_widget(progdlg_xml, widget_progdlg); 
 	
 	progbar = GTK_PROGRESS_BAR(glade_xml_get_widget(progdlg_xml, widget_progdlg_progbar));	
+    gtk_progress_bar_set_text(progbar, " ");
 	textview = GTK_TEXT_VIEW(glade_xml_get_widget(progdlg_xml, widget_progdlg_output));
 	textBuffer = gtk_text_view_get_buffer(textview);	
 	textviewScroll = glade_xml_get_widget(progdlg_xml, widget_progdlg_output_scroll);
+    
+    GtkWidget* processtitle = glade_xml_get_widget(progdlg_xml, widget_progdlg_processtitle);      
+    gchar* markup = g_strdup_printf("<b><big>%s</big></b>", exec->processtitle);
+    gtk_label_set_text(GTK_LABEL(processtitle), markup);
+    gtk_label_set_use_markup(GTK_LABEL(processtitle), TRUE);
+    g_free(markup);
+    
+    GtkWidget* processdesc = glade_xml_get_widget(progdlg_xml, widget_progdlg_processdescription);
+    gtk_label_set_text(GTK_LABEL(processdesc), exec->processdescription);
 	
-	GtkWidget* widget = glade_xml_get_widget(progdlg_xml, widget_progdlg);		
-	gtk_window_get_size(GTK_WINDOW(widget), &x, &y);
+    gbcommon_center_window_on_parent(widget);
+    gtk_main_iteration();
 	return widget;
 }
 
@@ -99,29 +117,13 @@ progressdlg_set_fraction(gfloat fraction)
 	   number of operations we are performing */
 	fraction *= (1.0/(gfloat)numberofexecs);			
 	fraction += ((gfloat)currentexec *(1.0/(gfloat)numberofexecs));
-	
 	gchar* percnt = g_strdup_printf("%d%%",(gint)(fraction * 100));
-	gdk_threads_enter();
 	gtk_progress_bar_set_fraction(progbar, fraction);
 	gtk_progress_bar_set_text(progbar, percnt);		
-	gdk_threads_leave();		
-	
 	g_free(percnt);
 }
 
 
-void 
-progressdlg_set_text(const gchar* text)
-{
-	GB_LOG_FUNC
-	g_return_if_fail(progbar != NULL);
-	
-	gdk_threads_enter();
-	gtk_progress_bar_set_text(progbar, text);		
-	gdk_threads_leave();
-}
-
-
 void 
 progressdlg_append_output(const gchar* output)
 {
@@ -130,21 +132,10 @@ progressdlg_append_output(const gchar* output)
 	g_return_if_fail(textBuffer != NULL);
 	
 	GtkTextIter textIter;
-
-	gdk_threads_enter();		
 	gtk_text_buffer_get_end_iter(textBuffer, &textIter);
 	gtk_text_buffer_insert(textBuffer, &textIter, output, strlen(output));	
 	gtk_text_iter_set_line(&textIter, gtk_text_buffer_get_line_count(textBuffer));
 	gtk_text_view_scroll_to_iter(textview, &textIter, 0.0, TRUE, 0.0, 0.0);		
-	gdk_threads_leave();
-}
-
-
-void 
-progressdlg_on_stop(GtkButton * button, gpointer user_data)
-{
-	GB_LOG_FUNC
-	burn_end_process();
 }
 
 
@@ -152,27 +143,8 @@ void
 progressdlg_on_close(GtkButton * button, gpointer user_data)
 {
 	GB_LOG_FUNC
-	gtk_dialog_response(GTK_DIALOG(glade_xml_get_widget(progdlg_xml, widget_progdlg)), 
-		GTK_RESPONSE_CLOSE);
-}
-
-
-void 
-progressdlg_enable_close(gboolean enable)
-{
-	GB_LOG_FUNC
-	g_return_if_fail(progdlg_xml != NULL);
-	
-	GtkWidget* closebutton = glade_xml_get_widget(progdlg_xml, widget_progdlg_close);
-	g_return_if_fail(closebutton != NULL);
-	
-	GtkWidget* stopbutton = glade_xml_get_widget(progdlg_xml, widget_progdlg_stop);
-	g_return_if_fail(stopbutton != NULL);
-	
-	/*gdk_threads_enter();*/
-	gtk_widget_set_sensitive(closebutton, enable);
-	gtk_widget_set_sensitive(stopbutton, !enable);
-	/*gdk_threads_leave();*/	
+	if(closefunction != NULL)
+        closefunction();
 }
 
 
@@ -182,41 +154,23 @@ progressdlg_set_status(const gchar* status)
 	GB_LOG_FUNC
 	g_return_if_fail(progdlg_xml != NULL);
 	
-	GtkWidget* statuslabel = glade_xml_get_widget(progdlg_xml, "statusLabel");
+	GtkWidget* statuslabel = glade_xml_get_widget(progdlg_xml, "label297");
 	g_return_if_fail(statuslabel != NULL);
-	
-	gdk_threads_enter();
-	gtk_label_set_text(GTK_LABEL(statuslabel), status);
+    gchar* markup = g_strdup_printf("<i>%s</i>", status);	
+	gtk_label_set_text(GTK_LABEL(statuslabel), markup);
 	gtk_label_set_use_markup(GTK_LABEL(statuslabel), TRUE);	
-	gdk_threads_leave();		
+    g_free(markup);
 }
 
 
 void 
-progressdlg_on_output(GtkButton * button, gpointer user_data)
+progressdlg_on_output(GtkExpander* expander, gpointer user_data)
 {
 	GB_LOG_FUNC
 	g_return_if_fail(progdlg_xml != NULL);
-	g_return_if_fail(textview != NULL);
-	g_return_if_fail(textviewScroll != NULL);
-		
-	showing = !showing;
-    GtkWidget* outputbuttonlabel = glade_xml_get_widget(progdlg_xml,widget_progdlg_toggleoutputlabel);
-    
-	if(!showing)
-	{
-		gtk_widget_show(GTK_WIDGET(textview));
-		gtk_widget_show(textviewScroll);
-	    gtk_label_set_label(GTK_LABEL(outputbuttonlabel),_("Hide Output"));
-	}
-	else
-	{
-		gtk_widget_hide(GTK_WIDGET(textview));
-		gtk_widget_hide(textviewScroll);		
-		gtk_window_resize(GTK_WINDOW(
-			glade_xml_get_widget(progdlg_xml, widget_progdlg)), x, y);
-		gtk_label_set_label(GTK_LABEL(outputbuttonlabel),_("View Output"));
-	}	
+    GtkWidget* label = gtk_expander_get_label_widget(expander);
+    gtk_label_set_text(GTK_LABEL(label), 
+        gtk_expander_get_expanded(expander) ? _("Show output"): _("Hide output"));
 }
 
 
@@ -224,7 +178,6 @@ gboolean
 progressdlg_on_delete(GtkWidget* widget, GdkEvent* event, gpointer user_data)
 {	
 	GB_LOG_FUNC
-	progressdlg_on_stop(NULL, user_data);
 	progressdlg_on_close(NULL, user_data);
 	return TRUE;
 }
@@ -235,11 +188,7 @@ progressdlg_pulse_ontimer(gpointer userdata)
 {
 	/*GB_LOG_FUNC*/
 	g_return_val_if_fail(progbar != NULL, TRUE);
-	
-	gdk_threads_enter();
 	gtk_progress_bar_pulse(progbar);		
-	gdk_threads_leave();	
-	
 	return TRUE;
 }
 
@@ -249,8 +198,8 @@ progressdlg_pulse_start()
 {
 	GB_LOG_FUNC
 	g_return_if_fail(progbar != NULL);
+    gtk_progress_bar_set_text(progbar, " ");
 	gtk_progress_bar_set_pulse_step(progbar, 0.01);		
-	
 	timertag = gtk_timeout_add(20, (GtkFunction)progressdlg_pulse_ontimer, NULL);	
 }
 
@@ -277,36 +226,42 @@ progressdlg_increment_exec_number()
 	
 	/* Clear out the text buffer so it only contains the current exec output */
 	GtkTextIter endIter, startIter;
-
-	gdk_threads_enter();			
 	gtk_text_buffer_get_end_iter(textBuffer, &endIter);		
 	gtk_text_buffer_get_start_iter(textBuffer, &startIter);	
 	gtk_text_buffer_delete(textBuffer, &startIter, &endIter);		
-	gdk_threads_leave();
 }
 
 
 void 
-progressdlg_reset_fraction(gfloat fraction)
+progressdlg_finish(GtkWidget* self, const Exec* ex)
 {
-	GB_LOG_FUNC
-	g_return_if_fail(progbar != NULL);
-	
-	gdk_threads_enter();
-	gtk_progress_bar_set_fraction(progbar, fraction);	
-	gdk_threads_leave();	
+    GB_LOG_FUNC
+    g_return_if_fail(self != NULL);
+    
+    if(ex->outcome != CANCELLED)
+    {
+        gtk_progress_bar_set_fraction(progbar, 1.0);
+        gtk_progress_bar_set_text(progbar, " ");
+        if(ex->outcome == COMPLETED)
+        {
+            progressdlg_set_status(_("Completed"));
+            if(preferences_get_bool(GB_PLAY_SOUND))
+                media_start_playing(PACKAGE_MEDIA_DIR"/BurnOk.wav");        
+        }
+        else if(ex->outcome == FAILED) 
+        {
+            progressdlg_set_status(_("Failed"));
+            if(preferences_get_bool(GB_PLAY_SOUND))
+               media_start_playing(PACKAGE_MEDIA_DIR"/BurnFailed.wav");        
+            if(ex->err != NULL)
+                progressdlg_append_output(ex->err->message);
+        }
+        /* Scrub out he closefunction callback as whatever exec was doing is finished */
+        closefunction = NULL;
+        /* Now we wait for the user to close the dialog */
+        gtk_dialog_run(GTK_DIALOG(self));
+    }
 }
 
 
-void
-progressdlg_dismiss()
-{
-	GB_LOG_FUNC
-	g_return_if_fail(progdlg_xml != NULL);	
 
-	GtkWidget* widget = glade_xml_get_widget(progdlg_xml, widget_progdlg);	
-	g_return_if_fail(widget != NULL);	
-	gdk_threads_enter();
-	gtk_dialog_response(GTK_DIALOG(widget), GTK_RESPONSE_CLOSE);
-	gdk_threads_leave();
-}
