@@ -26,6 +26,11 @@
 #include "preferences.h"
 
 
+/* Select device dialog widget names */
+static const gchar* const widget_select_writer = "optmenWriter";
+static const gchar* const widget_select_device_dlg = "selectDeviceDlg";
+
+
 GladeXML* selectdevicedlgdlg_xml = NULL;
 
 
@@ -39,7 +44,9 @@ selectdevicedlg_new(void)
 	GtkWidget *optmenWriteDev = glade_xml_get_widget(selectdevicedlgdlg_xml, widget_select_writer);
 	devices_populate_optionmenu(optmenWriteDev, GB_WRITER);
 	
-	return glade_xml_get_widget(selectdevicedlgdlg_xml, widget_select_device_dlg);	
+    GtkWidget* dlg = glade_xml_get_widget(selectdevicedlgdlg_xml, widget_select_device_dlg); 
+    gbcommon_center_window_on_parent(dlg);
+	return dlg;
 }
 
 
